@@ -1,7 +1,7 @@
 using Plots, Test
 using Unitful
 using Unitful: m, cm, s, DimensionError
-using Latexify, UnitfulLatexify
+using Latexify
 # Some helper functions to access the subplot labels and the series inside each test plot
 xguide(pl, idx = length(pl.subplots)) = Plots.get_guide(pl.subplots[idx].attr[:xaxis])
 yguide(pl, idx = length(pl.subplots)) = Plots.get_guide(pl.subplots[idx].attr[:yaxis])
